@@ -17,10 +17,25 @@ from sys import stderr
 
 import confuse
 
-__version__ = "2.4.0"
+from .util import deprecate_imports
+
+__version__ = "2.5.1"
 __author__ = "Adrian Sampson <adrian@radbox.org>"
 
 
+def __getattr__(name: str):
+    """Handle deprecated imports."""
+    return deprecate_imports(
+        old_module=__name__,
+        new_module_by_name={
+            "art": "beetsplug._utils",
+            "vfs": "beetsplug._utils",
+        },
+        name=name,
+        version="3.0.0",
+    )
+
+
 class IncludeLazyConfig(confuse.LazyConfig):
     """A version of Confuse's LazyConfig that also merges in data from
     YAML files specified in an `include` setting.
